//===================================================================
// This file is provided as part of the ClearImage COM Development Kit
// 
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT  
// WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,  
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES  
// OF MERCHANTABILITY AND/OR FITNESS FOR A  PARTICULAR PURPOSE. 
// 
// Copyright (C) 2003-2019.  Inlite Research, Inc. All rights reserved 
//===================================================================

#include "stdafx.h"
#include <stdio.h>			

void DisplayBarcode (ICiBarcodePtr &Bc)
	{
	cout <<  "  Type=" << Bc->Type;
	cout <<  "  Length=" << Bc->Length;
	cout <<  "  Text=" <<  Bc->Text;
	}

//========================================================
void DisplayHexBarcodeData (ICiBarcodePtr &Bc)
	{
	VARIANT &pData = Bc->Data;
	long UpperBounds, LowerBounds, i;
	unsigned char*	pByte; 
		// Check array structure
	if (pData.vt != (VT_ARRAY | VT_UI1)) 
		goto DoError;
	if (SafeArrayGetDim(pData.parray) != 1) 
		goto DoError;
	SafeArrayGetLBound(pData.parray, 1, &LowerBounds);
    SafeArrayGetUBound(pData.parray, 1, &UpperBounds);
	if (LowerBounds != 0) 
		goto DoError;
		//  Access bytes in safe array
	SafeArrayAccessData (pData.parray, reinterpret_cast <void **> (&pByte));
	cout << "HEX DATA   LBound=" << LowerBounds << "  UBound=" << UpperBounds << endl;
	for (i = 0; i <= UpperBounds; i++, pByte++)
		{
		if (!(i % 16) && i)
			cout << endl;	// 16 char in a row
		char buf[10];  sprintf(buf, "%02x", *pByte);
		cout << buf << " ";
		}
	cout << endl;
		// Terminate
	SafeArrayUnaccessData(pData.parray);
	return;

DoError:
	cout << " Incorrect Data format" << endl;
	return;
	}

void DisplayBarcodes (ICiBarcodesPtr &barcodes)
	{
	cout << "  TOTAL " << barcodes->Count << " barcodes" << endl;
	for (int i = 1 ; i <= barcodes->Count; i++)
		{
		DisplayBarcode(barcodes->Item[i]);
		DisplayHexBarcodeData(barcodes->Item[i]);
		}
	}

bool ReadBarcodePro (ICiServerPtr &Ci, ICiImagePtr &Image)
	{
	try 
		{
		ICiBarcodeProPtr reader;	
		reader =  Ci->CreateBarcodePro ();
			//  Attach image
		reader->Image = Image;
		// reader->Directions = (FBarcodeDirections)(cibHorz | cibVert);  // Direction setting example
		// reader->TbrCode = 103;	// TBR Code setting example
#if 1
		reader->AutoDetect1D = ciTrue;
		cout << "===========================" << endl <<
					 "CiBarcodePro: All 1D Barcodes  on '" << Image->FileName << "' Page:" << Image->PageNumber << endl;
#else
		reader->Type = (FBarcodeType) (cibfCode39 | cibfCode128);
		cout << "===========================" << endl <<
					 "CiBarcodePro: Code39 and Code128 on '" << Image->FileName << "' Page:" << Image->PageNumber << endl;
#endif
		reader->Find(0);
		DisplayBarcodes(reader->Barcodes);
		return true;
		}
	catch (_com_error &ex)
		{
		dump_com_error(ex);
		return false;
		}
	}


//########################################################################
bool ReadBarcodePdf417 (ICiServerPtr &Ci, ICiImagePtr &Image)
	{
	try 
		{ 
		ICiPdf417Ptr reader;	
		reader =  Ci->CreatePdf417 ();
			//  Attach image
		reader->Image = Image;
		// reader->Directions = (FBarcodeDirections)(cibHorz | cibVert);  // Direction setting example
		// reader->TbrCode = 103;	// TBR Code setting example
		cout << "===========================" << endl <<
						 "CiPdf417: Find all on '"<< Image->FileName << "' Page:" << Image->PageNumber << endl;
		reader->Find(0);
		DisplayBarcodes(reader->Barcodes);
		return true;
		}
	catch (_com_error &ex)
		{
		dump_com_error(ex);
		return false;
		}
	}

//########################################################################
bool ReadBarcodeDataMatrix (ICiServerPtr &Ci, ICiImagePtr &Image)
	{
	try 
		{
		ICiDataMatrixPtr reader;	
		reader =  Ci->CreateDataMatrix ();
			//  Attach image
		reader->Image = Image;
		// reader->Directions = (FBarcodeDirections)(cibHorz | cibVert);  // Direction setting example
		// reader->TbrCode = 103;	// TBR Code setting example
		cout << "===========================" << endl <<
						 "CiDataMatrix: Find all on '"<< Image->FileName << "' Page:" << Image->PageNumber << endl;
		reader->Find(0);
		DisplayBarcodes(reader->Barcodes);
		return true;
		}
	catch (_com_error &ex)
		{
		dump_com_error(ex);
		return false;
		}
	}



//########################################################################
bool ReadBarcodeQR (ICiServerPtr &Ci, ICiImagePtr &Image)
	{
	try 
		{
		ICiQRPtr reader;	
		reader =  Ci->CreateQR ();
			//  Attach image
		reader->Image = Image;
		// reader->Directions = (FBarcodeDirections)(cibHorz | cibVert);  // Direction setting example
		// reader->TbrCode = 103;	// TBR Code setting example
		cout << "===========================" << endl <<
						 "CiQR: Find all on '"<< Image->FileName << "' Page:" << Image->PageNumber << endl;
		reader->Find(0);
		DisplayBarcodes(reader->Barcodes);
		return true;
		}
	catch (_com_error &ex)
		{
		dump_com_error(ex);
		return false;
		}
	}


