//===================================================================
// This file is provided as part of the ClearImage COM Development Kit
// 
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT  
// WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,  
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES  
// OF MERCHANTABILITY AND/OR FITNESS FOR A  PARTICULAR PURPOSE. 
// 
// Copyright (C) 2003-2019.  Inlite Research, Inc. All rights reserved 
//===================================================================

#include "stdafx.h"
#include <stdio.h>

bool ReadBarcodePro (ICiServerPtr &Ci, ICiImagePtr &Image);
bool ReadBarcodePdf417 (ICiServerPtr &Ci, ICiImagePtr &Image);
bool ReadBarcodeDataMatrix (ICiServerPtr &Ci, ICiImagePtr &Image);
bool ReadBarcodeQR (ICiServerPtr &Ci, ICiImagePtr &Image);

//===============================================================
int main(int argc, char* argv[])
	{
	long nMasterId = 0;
	if (argc > 1)
		nMasterId = atol (argv[1]);
		//  Initailzie COM
	CoInitialize(NULL);
		//  Create External object]
	try 
		{
		char s[256];
		ICiServerPtr Ci;
			// Create server
		HRESULT hr = Ci.CreateInstance(__uuidof(CiServer));
		if (FAILED(hr)) _com_issue_error (hr);
			//  Open License
		if (nMasterId > 0)
			Ci->OpenExt ((long) GetModuleHandle(NULL), nMasterId, 0);
			//  Display server status info
		cout << "ClearImage COM Version  " 
				 << Ci->VerMajor << "." << Ci->VerMinor << "." << Ci->VerRelease << endl;
		cout << Ci->GetInfo(ciModulesList, 0) << endl;
			//  Process files
		for( ; ; )
			{
			cout << "Enter \"q\" to quit, or file name: ";
			cin.getline (s, sizeof(s));
			if(!stricmp(s, "q"))
					break;
			if (strlen(s) == 0)
				continue;
				// Delete quotes ("xxxx")
			if ((strlen(s) > 2)  && (*s == '\"') && (*(s + strlen(s) - 1) == '\"'))
				{
				strcpy (s, s+1);
				*(s + strlen(s) - 1) = 0;
				}
			ICiImagePtr Image = Ci->CreateImage();
			ICiPdfPtr pdf = Image->Pdf;
			int n = pdf->dpiRasterBw;
			Image->Open (_bstr_t(s), 1);
			ReadBarcodePro (Ci, Image);
			ReadBarcodePdf417 (Ci, Image);
			ReadBarcodeDataMatrix (Ci, Image);		
			ReadBarcodeQR (Ci, Image);		
			}
		}
	catch (_com_error &ex)
		{
		dump_com_error(ex);
		cout << "Press Enter to continue" << endl;
		cout.flush();
		getchar();
		}
	CoUninitialize();
	return 0;
}

//============================================================
void dump_com_error( _com_error &e ) 
	{ 
	char sMsg[256];
	if (e.Description().length())
		sprintf (sMsg, "=====> COM error: Code: %08lx  Description: %s" , 
						e.Error(), (LPCSTR)e.Description()); 
	else
		sprintf (sMsg, "=====> COM error: Code: %08lx  Message: %s" , 
						e.Error(), (LPCSTR)e.ErrorMessage()); 
		
	cout << sMsg << endl;	
	}
